@@ -1,5 +1,5 @@
 /* Copyright (C) 1998 Ian Zimmerman <itz@transbay.net> */
-/* $Id: acconfig.h,v 1.1.1.1 1999/09/14 15:29:41 paci Exp $ */
+/* Copyright (C) 2002 Nico Schottelius <nico@schottelius.org> */
 
 @TOP@
 
@@ -9,6 +9,10 @@
 /* RMEV release number as a string. */
 #define RMEV_RELEASE ""
 
-/* define if the __u32 type exists either in sys/types.h or in
-   linux/types.h */
+/* PATHS */
+#define SYSCONFDIR ""
+#define SBINDIR    ""
+
+
+/* define if the __u32 type exists either in sys/types.h or in linux/types.h */
 #undef HAVE___U32
