@@ -77,7 +77,7 @@
 
 #include "headers/gpm.h"
 #include "headers/synaptics.h"
-#include "headers/wd.h"
+#include "headers/message.h"
 
 #define DEBUG                   1
 #define DEBUG_PARAMS            1
@@ -166,7 +166,9 @@ typedef enum {
   No_Action          = 0,
   Left_Button_Action,
   Middle_Button_Action,
-  Right_Button_Action
+  Right_Button_Action,
+  Up_Button_Action,
+  Down_Button_Action
 } action_type;
 
 typedef struct {
@@ -212,43 +214,43 @@ typedef struct {
 
 static param_data_type param_data [] = {
   /* enabling configuration parameters */
-  { "edge_motion_enabled",        Flag_Param,    &edge_motion_enabled        },
-  { "edge_motion_speed_enabled",  Flag_Param,    &edge_motion_speed_enabled  },
-  { "corner_taps_enabled",        Flag_Param,    &corner_taps_enabled        },
-  { "taps_enabled",               Flag_Param,    &taps_enabled               },
-  { "pressure_speed_enabled",     Flag_Param,    &pressure_speed_enabled     },
-  { "tossing_enabled",            Flag_Param,    &tossing_enabled            },
-  { "does_toss_use_static_speed", Flag_Param,    &does_toss_use_static_speed },
+  { "edge_motion_enabled",        Flag_Param,    {&edge_motion_enabled}      },
+  { "edge_motion_speed_enabled",  Flag_Param,    {&edge_motion_speed_enabled}},
+  { "corner_taps_enabled",        Flag_Param,    {&corner_taps_enabled}      },
+  { "taps_enabled",               Flag_Param,    {&taps_enabled}             },
+  { "pressure_speed_enabled",     Flag_Param,    {&pressure_speed_enabled}   },
+  { "tossing_enabled",            Flag_Param,    {&tossing_enabled}          },
+  { "does_toss_use_static_speed", Flag_Param,    {&does_toss_use_static_speed}},
   /* pressure induced speed related configuration parameters */
-  { "low_pressure",               Integer_Param, &low_pressure               },
-  { "speed_up_pressure",          Integer_Param, &speed_up_pressure          },
-  { "pressure_factor",            Float_Param,   &pressure_factor            },
-  { "standard_speed_factor",      Float_Param,   &standard_speed_factor      },
+  { "low_pressure",               Integer_Param, {&low_pressure}             },
+  { "speed_up_pressure",          Integer_Param, {&speed_up_pressure}        },
+  { "pressure_factor",            Float_Param,   {&pressure_factor}          },
+  { "standard_speed_factor",      Float_Param,   {&standard_speed_factor}    },
   /* toss/catch related parameters */
-  { "min_toss_time",              Integer_Param, &min_toss_time              },
-  { "max_toss_time",              Integer_Param, &max_toss_time              },
-  { "toss_cleanup_time",          Integer_Param, &toss_cleanup_time          },
-  { "min_toss_dist",              Integer_Param, &min_toss_dist              },
-  { "static_toss_speed",          Integer_Param, &static_toss_speed          },
-  { "toss_speed_factor",          Float_Param,   &toss_speed_factor          },
+  { "min_toss_time",              Integer_Param, {&min_toss_time}            },
+  { "max_toss_time",              Integer_Param, {&max_toss_time}            },
+  { "toss_cleanup_time",          Integer_Param, {&toss_cleanup_time}        },
+  { "min_toss_dist",              Integer_Param, {&min_toss_dist}            },
+  { "static_toss_speed",          Integer_Param, {&static_toss_speed}        },
+  { "toss_speed_factor",          Float_Param,   {&toss_speed_factor}        },
   /* edge motion related configuration parameters */
-  { "edge_speed",                 Integer_Param, &edge_speed                 },
+  { "edge_speed",                 Integer_Param, {&edge_speed}               },
   /* corner tap actions */
-  { "upper_left_action",          Corner_Param,  &corner_actions [0]         },
-  { "lower_left_action",          Corner_Param,  &corner_actions [1]         },
-  { "upper_right_action",         Corner_Param,  &corner_actions [2]         },
-  { "lower_right_action",         Corner_Param,  &corner_actions [3]         },
+  { "upper_left_action",          Corner_Param,  {&corner_actions [0]}       },
+  { "lower_left_action",          Corner_Param,  {&corner_actions [1]}       },
+  { "upper_right_action",         Corner_Param,  {&corner_actions [2]}       },
+  { "lower_right_action",         Corner_Param,  {&corner_actions [3]}       },
   /* use wmode */
-  { "use_wmode",		  Flag_Param,	 &use_wmode		     },
-  { "finger_threshold",		  Integer_Param, &finger_threshold	     },
-  { "tap_lower_limit",		  Integer_Param, &tap_lower_limit	     },
-  { "tap_upper_limit",		  Integer_Param, &tap_upper_limit	     },
-  { "tap_range",		  Integer_Param, &tap_range		     },
-  { "tap_interval",		  Integer_Param, &tap_interval		     },
-  { "drag_lock",		  Flag_Param,	 &drag_lock		     },
-  { "multiple_click_delay",	  Integer_Param, &multiple_click_delay	     },
+  { "use_wmode",		  Flag_Param,	 {&use_wmode}		     },
+  { "finger_threshold",		  Integer_Param, {&finger_threshold}	     },
+  { "tap_lower_limit",		  Integer_Param, {&tap_lower_limit}	     },
+  { "tap_upper_limit",		  Integer_Param, {&tap_upper_limit}	     },
+  { "tap_range",		  Integer_Param, {&tap_range}		     },
+  { "tap_interval",		  Integer_Param, {&tap_interval}	     },
+  { "drag_lock",		  Flag_Param,	 {&drag_lock}		     },
+  { "multiple_click_delay",	  Integer_Param, {&multiple_click_delay}     },
   /* end of list */
-  { NULL,                         Flag_Param,    NULL                        }
+  { NULL,                         Flag_Param,    {NULL}                      }
 };
 
 
@@ -495,6 +497,12 @@ void process_corner_taps (Gpm_Event *state, report_type report)
 	case Right_Button_Action:
 	  last_corner = GPM_B_RIGHT;
 	  break;
+	case Up_Button_Action:
+	  last_corner = GPM_B_UP;
+	  break;
+	case Down_Button_Action:
+	  last_corner = GPM_B_DOWN;
+	  break;
 	case No_Action:
 	default:
 	  last_corner = 0;
@@ -518,8 +526,7 @@ void process_corner_taps (Gpm_Event *state, report_type report)
 static void dump_report_data (report_type report,
 			      int edges) 
 {
-  gpm_debug_log (LOG_DEBUG,
-                 "\r%c%c%c%c%c  %4dx%-4d  %3d  %c%c%c%c  %c%c",
+  gpm_report(GPM_PR_DEBUG, "\r%c%c%c%c%c  %4dx%-4d  %3d  %c%c%c%c  %c%c",
                  report.gesture ? 'g' : '-',
                  report.finger  ? 'f' : '-',  
 
@@ -646,7 +653,7 @@ static void syn_process_data (Gpm_Event *state,
       dy = touch_loc.y - last_locs [mod4 (packet_num - 1)].y;
 
 #if DEBUG_TOSS
-      gpm_debug_log (LOG_DEBUG,"dx: %2.1f  dy: %2.1f  tdist^2: %2.1f",
+      gpm_report (GPM_PR_DEBUG,"dx: %2.1f  dy: %2.1f  tdist^2: %2.1f",
                      dx, dy, distance (dx, dy));
 #endif
 
@@ -665,7 +672,7 @@ static void syn_process_data (Gpm_Event *state,
 	}
 
 #if DEBUG_TOSS
-	gpm_debug_log (LOG_DEBUG,"tossx: %d  tossy: %d", toss_speed.x, toss_speed.y);
+	gpm_report (GPM_PR_DEBUG,"tossx: %d  tossy: %d", toss_speed.x, toss_speed.y);
 #endif
       }
     }
@@ -704,7 +711,7 @@ static void syn_process_data (Gpm_Event *state,
 	state->buttons |= GPM_B_MIDDLE;
 
       if (report.down)
-	state->buttons |= 0x8;
+	state->buttons |= GPM_B_FOURTH;
 
       process_corner_taps (state, report);
     }
@@ -749,7 +756,7 @@ void syn_read_config_file ()
 
 	  /* was a param found? */
 	  if (!param_data [param].name) {
-	    gpm_debug_log (LOG_NOTICE,"Unknown parameter %s", token);
+	    gpm_report (GPM_PR_INFO,"Unknown parameter %s", token);
 	  } else {
 	    token = strtok (NULL, "[] ");
 
@@ -757,10 +764,10 @@ void syn_read_config_file ()
 	    case Integer_Param:
 	      *(param_data [param].addr.int_p) = strtol (token, &end_ptr, 0);
 	      if (end_ptr == token)
-		gpm_debug_log (LOG_NOTICE,"Value (%s) for parameter %s is invalid",
+		gpm_report (GPM_PR_INFO,"Value (%s) for parameter %s is invalid",
                                token, param_data [param].name);
 #if DEBUG_PARAMS
-	      gpm_debug_log (LOG_DEBUG,"Param %s set to %d",
+	      gpm_report (GPM_PR_DEBUG,"Param %s set to %d",
                              param_data [param].name,
                              *(param_data [param].addr.int_p));
 #endif
@@ -769,10 +776,10 @@ void syn_read_config_file ()
 	    case Float_Param:
 	      *(param_data [param].addr.float_p) = strtod (token, &end_ptr);
 	      if (end_ptr == token)
-		gpm_debug_log (LOG_NOTICE,"Value (%s) for parameter %s is invalid",
+		gpm_report (GPM_PR_INFO,"Value (%s) for parameter %s is invalid",
                                token, param_data [param].name);
 #if DEBUG_PARAMS
-	      gpm_debug_log (LOG_DEBUG,"Param %s set to %3.3f",
+	      gpm_report (GPM_PR_DEBUG,"Param %s set to %3.3f",
                              param_data [param].name,
                              *(param_data [param].addr.float_p));
 #endif
@@ -784,11 +791,11 @@ void syn_read_config_file ()
 	      } else if (index ("NnFf0", token [0])) {
 		*(param_data [param].addr.flag_p) = 0;
 	      } else {
-		gpm_debug_log (LOG_NOTICE,"Value (%s) for parameter %s is invalid",
+		gpm_report (GPM_PR_INFO,"Value (%s) for parameter %s is invalid",
                                token, param_data [param].name);
 	      }
 #if DEBUG_PARAMS
-	      gpm_debug_log (LOG_DEBUG,"Param %s set to %s",
+	      gpm_report (GPM_PR_DEBUG,"Param %s set to %s",
                              param_data [param].name,
                              (*(param_data [param].addr.flag_p) ?
                               "True" : "False"));
@@ -799,10 +806,10 @@ void syn_read_config_file ()
 	      param_data [param].addr.corner_p->action = strtol (token,
 								 &end_ptr, 0);
 	      if (end_ptr == token)
-		gpm_debug_log (LOG_NOTICE,"Value (%s) for parameter %s is invalid",
+		gpm_report (GPM_PR_INFO,"Value (%s) for parameter %s is invalid",
                                token, param_data [param].name);
 #if DEBUG_PARAMS
-	      gpm_debug_log (LOG_DEBUG,"Param %s set to %d",
+	      gpm_report (GPM_PR_DEBUG,"Param %s set to %d",
                              param_data [param].name,
                              param_data [param].addr.corner_p->action);
 #endif
@@ -851,26 +858,26 @@ static void syn_process_config (info_type ident,
   toss_cleanup_packets = toss_cleanup_time * 80 / 1000;
 
 #if DEBUG
-  gpm_debug_log (LOG_DEBUG,"Synaptics Ident:  model_code=%d   Firmware version %d.%d",
+  gpm_report (GPM_PR_DEBUG,"Synaptics Ident:  model_code=%d   Firmware version %d.%d",
                  ident.info_model_code, ident.info_major, ident.info_minor);
-  gpm_debug_log (LOG_DEBUG,"Synaptics model:");
-  gpm_debug_log (LOG_DEBUG,"   rot180:      %s", model.info_rot180 ? "Yes" : "No");
-  gpm_debug_log (LOG_DEBUG,"   portrait:    %s", model.info_portrait ? "Yes" : "No");
-  gpm_debug_log (LOG_DEBUG,"   sensor:      %d", model.info_sensor);
-  gpm_debug_log (LOG_DEBUG,"                %s", syn_model_name (model.info_sensor));
-  gpm_debug_log (LOG_DEBUG,"                %s", sensor->model);
-  gpm_debug_log (LOG_DEBUG,"                %dx%d res/mm",
+  gpm_report (GPM_PR_DEBUG,"Synaptics model:");
+  gpm_report (GPM_PR_DEBUG,"   rot180:      %s", model.info_rot180 ? "Yes" : "No");
+  gpm_report (GPM_PR_DEBUG,"   portrait:    %s", model.info_portrait ? "Yes" : "No");
+  gpm_report (GPM_PR_DEBUG,"   sensor:      %d", model.info_sensor);
+  gpm_report (GPM_PR_DEBUG,"                %s", syn_model_name (model.info_sensor));
+  gpm_report (GPM_PR_DEBUG,"                %s", sensor->model);
+  gpm_report (GPM_PR_DEBUG,"                %dx%d res/mm",
 	  sensor->x_per_mm, sensor->y_per_mm);
-  gpm_debug_log (LOG_DEBUG,"                %4.1fx%4.1f mm",
+  gpm_report (GPM_PR_DEBUG,"                %4.1fx%4.1f mm",
 	  sensor->width_mm, sensor->height_mm);
-  gpm_debug_log (LOG_DEBUG,"                %dx%d res", res_x, res_y);
-  gpm_debug_log (LOG_DEBUG,"   hardware:    %d", model.info_hardware);
-  gpm_debug_log (LOG_DEBUG,"   newABS:      %s", model.info_new_abs ? "Yes" : "No");
-  gpm_debug_log (LOG_DEBUG,"   simpleCmd:   %s", model.info_simple_cmd ? "Yes" : "No");
-  gpm_debug_log (LOG_DEBUG,"   geometry:    %d", model.info_geometry);
+  gpm_report (GPM_PR_DEBUG,"                %dx%d res", res_x, res_y);
+  gpm_report (GPM_PR_DEBUG,"   hardware:    %d", model.info_hardware);
+  gpm_report (GPM_PR_DEBUG,"   newABS:      %s", model.info_new_abs ? "Yes" : "No");
+  gpm_report (GPM_PR_DEBUG,"   simpleCmd:   %s", model.info_simple_cmd ? "Yes" : "No");
+  gpm_report (GPM_PR_DEBUG,"   geometry:    %d", model.info_geometry);
 #endif
 #if DEBUG_TOSS
-  gpm_debug_log (LOG_DEBUG,"\nMin Toss Dist^2: %d\n", min_toss_dist__2);
+  gpm_report (GPM_PR_DEBUG,"\nMin Toss Dist^2: %d\n", min_toss_dist__2);
 #endif
 }
 
@@ -907,12 +914,12 @@ static void ser_flush_input (int fd)
 
   while (select (fd+1, &rfds, NULL, NULL, &tv) == 1) {
 #if DEBUG_FLUSH
-    gpm_debug_log (LOG_DEBUG,"tossing");
+    gpm_report (GPM_PR_DEBUG,"tossing");
     fflush (stdout);
 #endif
     read (fd, &junk, 1);
 #if DEBUG_FLUSH
-    gpm_debug_log (LOG_DEBUG," %c", junk);
+    gpm_report (GPM_PR_DEBUG," %c", junk);
 #endif
     FD_ZERO(&rfds);
     FD_SET (fd, &rfds);
@@ -960,7 +967,7 @@ static void ser_send_cmd(int fd,
   ser_read (fd, junk, strlen (cmd));
 #if DEBUG_FLUSH
   junk [strlen (cmd)] = '\0';
-  gpm_debug_log (LOG_DEBUG,"tossing: %s", junk);
+  gpm_report (GPM_PR_DEBUG,"tossing: %s", junk);
 #endif
 }
 
@@ -972,7 +979,7 @@ static void syn_set_serial_mode (int fd,
 
   sprintf (bytes, "%%C3B%02X5555", mode);
 #if DEBUG_SENT_DATA
-  gpm_debug_log (LOG_DEBUG,"modes: %s", bytes);
+  gpm_report (GPM_PR_DEBUG,"modes: %s", bytes);
 #endif
   ser_send_cmd (fd, bytes);
 }
@@ -988,7 +995,7 @@ static void syn_read_serial_ident (int fd,
 
 #if DEBUG_SENT_DATA
   bytes [4] = '\0';
-  gpm_debug_log (LOG_DEBUG,"Serial ident: %s", bytes);
+  gpm_report (GPM_PR_DEBUG,"Serial ident: %s", bytes);
 #endif
 
   /* reformat the data */
@@ -1015,7 +1022,7 @@ static void syn_read_serial_model_id (int fd,
 
 #if DEBUG_SENT_DATA
   bytes [6] = '\0';
-  gpm_debug_log (LOG_DEBUG,"Serial model id: %s", bytes);
+  gpm_report (GPM_PR_DEBUG,"Serial model id: %s", bytes);
 #endif
 
   /* reformat the data */
@@ -1055,7 +1062,7 @@ static void ps2_putbyte(int fd,
   write(fd, &b, 1);
   read(fd, &ack, 1);
   if (ack != 0xFA)
-    gpm_debug_log (LOG_ERR,"Invalid ACK in synps2 initialization");
+    gpm_report (GPM_PR_ERR,"Invalid ACK in synps2 initialization");
 }
 
 /* read a byte from the ps/2 port */
@@ -1119,7 +1126,7 @@ static void syn_read_ps2_ident (int fd,
 
   ps2_status_rqst (fd, 0x00, bytes);
   if (bytes [1] != 0x47) {
-    printf ("PS/2 device doesn't appear to be a synaptics touchpad\n");
+    gpm_report(GPM_PR_DEBUG,"PS/2 device doesn't appear to be a synaptics touchpad\n");
   } else {
     info->info_minor      = bytes [0];
     info->info_model_code = (bytes [2] >> 4) & 0x0f;
@@ -1162,7 +1169,7 @@ static void read_ps2_modes (int fd)
 
   ps2_status_rqst (fd, 0x01, bytes);
 #if DEBUG_SENT_DATA
-  gpm_debug_log (LOG_DEBUG,"PS/2 modes: %02X", bytes [2]);
+  gpm_report (GPM_PR_DEBUG,"PS/2 modes: %02X", bytes [2]);
 #endif
 }
 
@@ -1203,9 +1210,9 @@ static void syn_translate_ps2_report (unsigned char *data,
     report->pressure = (((data [0] & 0x30) << 2 ) |
 			(data [3] & 0x3f));
   } else {
-    gpm_debug_log (LOG_NOTICE,"tossing PS/2 data: ");
+    gpm_report (GPM_PR_INFO,"tossing PS/2 data: ");
     for (i = 0; i < 6; i++)
-      gpm_debug_log (LOG_NOTICE,"%02X ", data [i]);
+      gpm_report (GPM_PR_INFO,"%02X ", data [i]);
     report->gesture  = 0;
     report->finger   = 0;
     report->left     = 0;
@@ -1229,9 +1236,12 @@ static void syn_translate_ps2_wmode_report (unsigned char *data,
   static int drag_locked = 0;
 
   if (((data[0] & 0xc8) == 0x80) && ((data[3] & 0xc8) == 0xc0)) {
-    unsigned int w = ((data[3] & 0x04) >> 2) |
+/*** GCC says this is an unused variables..so we remove it **/
+ 
+/*    unsigned int w = ((data[3] & 0x04) >> 2) |
 	    		((data[0] & 0x04) >> 1) |
-			((data[0] & 0x30) >> 2);
+			((data[0] & 0x30) >> 2); */
+
     report->left     = check_bits (data[0], 0x01);
     report->middle   = check_bits (data[0] ^ data[3], 0x01);
     report->down     = check_bits (data[0] ^ data[3], 0x02);
@@ -1296,9 +1306,9 @@ static void syn_translate_ps2_wmode_report (unsigned char *data,
     report->left = (report->left || report->gesture);
 
   } else {
-    gpm_debug_log (LOG_NOTICE,"tossing PS/2 data: ");
+    gpm_report (GPM_PR_INFO,"tossing PS/2 data: ");
     for (i = 0; i < 6; i++)
-      gpm_debug_log (LOG_NOTICE,"%02X ", data [i]);
+      gpm_report (GPM_PR_INFO,"%02X ", data [i]);
     report->gesture  = 0;
     report->finger   = 0;
     report->left     = 0;
@@ -1361,7 +1371,7 @@ void syn_serial_init (int fd)
   model_id_type     model;
   info_type         ident;
 
-  puts ("Initializing Synaptics serial TouchPad");
+  gpm_report(GPM_PR_DEBUG,"Initializing Synaptics serial TouchPad");
 
   syn_read_serial_ident (fd, &ident);
   syn_read_serial_model_id (fd, &model);
@@ -1389,7 +1399,7 @@ void syn_ps2_init (int fd)
   info_type         ident;
   ext_cap_type      cap;
 
-  puts ("Initializing Synaptics PS/2 TouchPad");
+  gpm_report(GPM_PR_DEBUG,"Initializing Synaptics PS/2 TouchPad");
 
   syn_read_ps2_ident (fd, &ident);
   syn_read_ps2_model_id (fd, &model);
